@@ -47,7 +47,7 @@ def handle_commands(poll, crawl, start, update):
             from src.dataset.database import TabayyunDB
             stdout("Applying schema...", color="yellow")
             stdout(f"Using database {bot_db}", color="yellow")
-            db_conn = TabayyunDB(Conf.BOT_DB)
+            db_conn = TabayyunDB(sqlite_db=Conf.BOT_DB)
             db_conn.apply_schema()
             stdout("Start crawling...", color="yellow")
             crawler.start(crawling_page)
