@@ -49,7 +49,7 @@ def start(limit: int = 10):
     api_key = os.environ['MAFINDO_API_KEY']
     mafindo_data = get_mafindo_data(api_key, limit)
 
-    engine = TabayyunDB().db_engine
+    engine = TabayyunDB(sqlite_db=Conf.BOT_DB).db_engine
     mafindo_df = pd.DataFrame(mafindo_data,
                               columns=['id', 'authors', 'status', 'classification', 'title', 'content', 'fact',
                                        'reference_link', 'source_issue', 'source_link', 'picture1', 'picture2',
