@@ -1,4 +1,5 @@
 import logging
+import re
 from functools import lru_cache
 from warnings import simplefilter
 
@@ -37,11 +38,15 @@ def get_cosine_sim(text: str):
             similarity_content = cosine_similarity(vectors_content)
             vectors_tittle = get_vectors(text.lower(), row['title'].lower())
             similarity_tittle = cosine_similarity(vectors_tittle)
+            logging.debug("Similarity with title : %s", similarity_tittle)
+            logging.debug("Similarity with content : %s", similarity_content)
             if similarity_tittle[0][1] > 0.70 or similarity_content[0][1] > 0.70:
                 return {"fact": row['fact'], "classification": row['classification'],
                         "conclusion": row['conclusion'], "references": [row['reference_link']]}
 
-        if text.lower() in row['content'].lower():
+        pattern = ".+".join(text.split())
+        str_finder = re.findall(pattern, row['title'], re.IGNORECASE)
+        if str_finder:
             fact = "Ditemukan beberapa artikel terkait topik tersebut" \
                 if len(set(link)) > 1 else "Ditemukan artikel terkait topik tersebut"
             link.append(f"{row['title']} - {row['reference_link']}")
@@ -52,5 +57,5 @@ def get_cosine_sim(text: str):
 
 if __name__ == '__main__':
     # Test sample message
-    msg = """[SALAH] Racikan Air Kelapa Muda, Jeruk Nipis, Garam, dan Madu dapat Membunuh Virus Covid-19"""
-    get_cosine_sim(msg)
+    msg = """Vaksin racun berbahaya"""
+    print(get_cosine_sim(msg))
